@@ -3,7 +3,7 @@
 import logging
 from typing import List, Optional
 
-from ..model import EntityType, EntityUpdate
+from ..model import EntityT, EntityUpdate
 from .abstract import AbstractSource
 
 log = logging.getLogger(__name__)
@@ -15,7 +15,7 @@ class RiskSource(AbstractSource):
     def update(
         self,
         resource_types: Optional[List[str]] = None,
-        active_resources: Optional[List[EntityType]] = None,
+        active_resources: Optional[List[EntityT]] = None,
     ) -> List[EntityUpdate]:
         """Get the latest state of the source entities.
 
