@@ -2,6 +2,7 @@
 
 import logging
 import sys
+from contextlib import suppress
 from typing import List, Optional
 
 import click
@@ -12,9 +13,11 @@ from rich.live import Live
 from rich.table import Table
 
 from .. import services, views
-from ..model import MODELS, RESOURCE_NAMES, Entity
+from ..model import MODELS, RESOURCE_NAMES, RESOURCE_TYPES
+from ..model.entity import EntityState
 from ..version import version_info
 from . import load_adapters, load_config, load_logger
+from .tui import PydanticQuestions
 
 log = logging.getLogger(__name__)
 
@@ -36,8 +39,9 @@ def cli(ctx: Context, config_path: str, verbose: bool) -> None:
     load_logger(verbose)
     config = load_config(config_path)
     ctx.obj["config"] = config
-    ctx.obj["repo"] = load_repository(config.database_url, MODELS)
+    ctx.obj["repo"] = load_repository(config.database_url, search_exception=False)
     ctx.obj["adapters"] = load_adapters(config)
+    ctx.obj["prompter"] = PydanticQuestions()
 
 
 @cli.command()
@@ -61,13 +65,23 @@ def update(ctx: Context, resource_types: List[str]) -> None:
 @click.argument("resource_id", type=str)
 def print_(ctx: Context, resource_id: str) -> None:
     """Print the information of the resource."""
-    try:
-        entity: Entity = ctx.obj["repo"].get(resource_id)
-    except EntityNotFoundError as error:
-        log.error(str(error))
-        sys.exit(1)
+    repo = ctx.obj["repo"]
 
-    views.print_entity(entity)
+    for model in MODELS:
+        with suppress(EntityNotFoundError):
+            entity = repo.get(resource_id, model)
+            repo.close()
+            views.print_entity(entity)
+            break
+
+    if not repo.is_closed:
+        model_names = [model.__name__ for model in MODELS]
+        log.error(
+            f'There are no entities of type {", ".join(model_names)} in the repository '
+            f"with id {resource_id}."
+        )
+        repo.close()
+        sys.exit(1)
 
 
 @cli.command(name="list")
@@ -87,7 +101,9 @@ def list_(
         )
     except EntityNotFoundError as error:
         log.error(str(error))
+        ctx.obj["repo"].close()
         sys.exit(1)
+    ctx.obj["repo"].close()
 
     views.list_entities(entities)
 
@@ -128,7 +144,9 @@ def search(
                 )
         except EntityNotFoundError as error:
             log.error(str(error))
+            ctx.obj["repo"].close()
             sys.exit(1)
+    ctx.obj["repo"].close()
 
 
 @cli.command(name="unused")
@@ -142,10 +160,34 @@ def unused(
 ) -> None:
     """Search resources that don't belong to a Service or Project."""
     entities = services.unused(ctx.obj["repo"], resource_types)
+    ctx.obj["repo"].close()
 
     views.list_entities(entities)
 
 
+@cli.command(name="add")
+@click.pass_context
+@click.argument(
+    "resource_type",
+    type=click.Choice(["pro", "ser", "per", "inf"]),
+)
+def add(ctx: Context, resource_type: str) -> None:
+    """Add resources."""
+    prompter = ctx.obj["prompter"]
+    repo = ctx.obj["repo"]
+    config = ctx.obj["config"]
+
+    model = RESOURCE_TYPES[resource_type]
+    choices = services.build_choices(repo, config, model)  # type: ignore
+    entity_data = {
+        "id_": services.next_id(repo, model),  # type: ignore
+        "state": EntityState.RUNNING,
+    }
+    resource = prompter.fill(model=model, choices=choices, entity_data=entity_data)
+
+    services.add(repo, resource)
+
+
 @cli.command(hidden=True)
 def null() -> None:
     """Do nothing.
